<?php

namespace Drupal\bookable_calendar;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the bookable calendar entity type.
 */
class BookableCalendarAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view bookable calendar');

      case 'update':
        return AccessResult::allowedIfHasPermissions($account, ['edit bookable calendar', 'administer bookable calendar'], 'OR');

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete bookable calendar', 'administer bookable calendar'], 'OR');

      default:
        // No opinion.
        return AccessResult::neutral();
    }

  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['create bookable calendar', 'administer bookable calendar'], 'OR');
  }

}
